@@ -8,7 +8,7 @@ import sys, os, time
 import ConfigParser
 from PyQt4.QtCore import *
 from PyQt4.QtGui import *
-import ctypes, sqlite3, uuid
+import ctypes, uuid
 
 # Information taken from:
 # http://docs.python.org/library/uuid.html#uuid.uuid4
@@ -44,8 +44,10 @@ class RTComElEvent(ctypes.Structure):
                 ("fld_pango_markup", ctypes.c_char_p)]
 
 def put_to_sent_sms(name, number, uniqueid, groupid, message):
-#    rtcom = ctypes.CDLL('librtcom-eventlogger.so.1') # PR 1.2
-    rtcom = ctypes.CDLL('librtcom-eventlogger.so.0') # PR 1.1
+    try:
+        rtcom = ctypes.CDLL('librtcom-eventlogger.so.1') # PR 1.2
+    except:
+        rtcom = ctypes.CDLL('librtcom-eventlogger.so.0') # PR 1.1
 
     el = ctypes.cast(rtcom.rtcom_el_new(), ctypes.c_void_p)
     event = ctypes.cast(rtcom.rtcom_el_event_new(), ctypes.POINTER(RTComElEvent))[0]
@@ -97,17 +99,8 @@ def put_to_sent_sms(name, number, uniqueid, groupid, message):
     rtcom.rtcom_el_event_free(ctypes.byref(event))
 
 def write_to_rtcomm(message, number):
-    connection = sqlite3.connect(os.path.join(os.environ['HOME'],
-                                     '.rtcom-eventlogger', 'el.db'))
-    cursor = connection.cursor()
-    cursor.execute('SELECT id FROM Events')
-    id_array = cursor.fetchall()
-    seq_id = max(id_array)[0] + 1
-        
     strippednumber = number[-7:]
-
     own_number = ""
-        
     put_to_sent_sms(own_number, number, 0, strippednumber, message)
 
 def octify(str):
@@ -171,7 +164,7 @@ def resetnumber(number):
             number = number + 'F'
         return number
 
-def createPDUstring(number, msg):
+def createPDUstring(number, msg, addr_type):
     '''
     Returns a list of bytes to represent a valid PDU message
     '''
@@ -179,12 +172,12 @@ def createPDUstring(number, msg):
     number = resetnumber(number)
     octifiednumber = [ semi_octify(number[i:i+2]) for i in range(0, len(number), 2) ]
         
-    HEADER = 1
+    HEADER = 33
     FIRSTOCTETOFSMSDELIVERMSG = 10
-    ADDR_TYPE = 129 #unknown format
+    #ADDR_TYPE = 129 #unknown format
     number_length = len(number)
     msg_length = len(msg)
-    pdu_message = [HEADER, FIRSTOCTETOFSMSDELIVERMSG, number_length, ADDR_TYPE]
+    pdu_message = [HEADER, FIRSTOCTETOFSMSDELIVERMSG, number_length, addr_type]
     pdu_message.extend(octifiednumber)
     pdu_message.append(0)
     pdu_message.append(0)
@@ -208,7 +201,14 @@ class SMS(object):
     '''
     
     def __init__(self, msg, number):
-        self.pdustring = createPDUstring(number, msg)
+        if number.find("+") > -1:
+          conv_number = number.replace('+', '')
+          addr_type = 129
+#        change ADDR_TYPE ?!? 129 = international, 4 = local
+        else:
+          conv_number = number
+          addr_type = 132
+        self.pdustring = createPDUstring(conv_number, msg, addr_type)
         write_to_rtcomm(msg, number)
 
     def send(self):
@@ -369,8 +369,13 @@ class MainWindow(QMainWindow, Ui_MainWindow):
             self.load_config(False)
         else:
             self.plainTextEditStatus.appendPlainText("Currently logged in") 
-        
+
     def on_pushButtonNext_released(self):
+        try:
+            self.msgWindow.setAttribute(Qt.WA_Maemo5StackedWindow)
+        except:
+               pass
+
         self.msgWindow.show()
 
 class MsgWindow(QMainWindow, Ui_MsgWindow):
@@ -415,7 +420,7 @@ class MsgWindow(QMainWindow, Ui_MsgWindow):
                         self.plainTextEditStatus.appendPlainText(message + "Success!")
                     else:
                         self.plainTextEditStatus.appendPlainText(message + "Failed!!")
-                    time.sleep(3)
+                    time.sleep(5)
             i = i + 1
             
         '''
